@@ -57,14 +57,9 @@ void ControlPanel::startPlot ( double *d, bool b)
 {
   Display->startPlot(d,b);
 }
-void ControlPanel::display()
+void ControlPanel::present(bool p)
 {
-  Display->show();
-}
-
-void ControlPanel::undisplay()
-{
-  Display->hide();
+  Display->showSpectren(p);
 }
 void ControlPanel::newChannel()
 {
@@ -83,6 +78,11 @@ void ControlPanel::enableSaveData()
 {
   QSO->enableSaveData();
 }
+void ControlPanel::setAutoDate()
+{
+  QSO->setAutoDate();
+}
+
 void ControlPanel::restoreSplitterStates(const QByteArray & controlState,const QByteArray & spectrumState)
 {
   controlSplitter->restoreState(controlState);
@@ -96,3 +96,7 @@ QByteArray ControlPanel::spectrumSplitterState() const
 {
   return Display->spectrumSplitterState();
 }
+void ControlPanel::initQsoData()
+{
+  QSO->initQsoData();
+}
