@@ -21,12 +21,13 @@ public:
     void insertMacros(Macros *);
     void setPhasePointer(std::complex<float> *);
     void setColorList(QList<QColor> *c);
-    void display();
-    void undisplay();
+    void present(bool p);
     void newChannel();
     void updateMacroWindow(int macroNumber);
     void insertMacros(QVector<Macro> *macroList);
     void enableSaveData();
+    void setAutoDate();
+    void initQsoData();
     void restoreSplitterStates(const QByteArray & controlState,const QByteArray & spectrumState);
     QByteArray controlSplitterState() const;
     QByteArray spectrumSplitterState() const;
