@@ -22,33 +22,38 @@
 #define GENERALSETTINGS_H
 
 #include <QDialog>
+#include <QStringList>
 #include "ui_generalsettings.h"
 class Parameter;
 class QButtonGroup;
 class QModelIndex;
+class QMenu;
+
 class GeneralSettings : public QDialog, private Ui::GeneralSettings
 {
   Q_OBJECT
 
 public:
-  GeneralSettings(QWidget* parent = 0, Qt::WFlags fl = 0 );
+  GeneralSettings(QWidget* parent = 0, Qt::WindowFlags fl = 0 );
   ~GeneralSettings();
 Parameter getSettings();
 
 public slots:
-  /*$PUBLIC_SLOTS$*/
 
 protected:
 QButtonGroup *FileFormat;
-  /*$PROTECTED_FUNCTIONS$*/
 Parameter LocalSettings;
+
+QMenu * selectionMenu;
 protected slots:
 void selectDemomode(bool);
-void setPTTDevice(const QModelIndex &);
+
 void selectFileLogging(bool);
 void selectLinLogLogging(bool);
 void setSampleRate(QString s);
 void setComplexFormat(bool);
+QStringList getSoundCards();
+
 };
 
 #endif
