@@ -1,11 +1,3 @@
-/***************************************************************************
-                          |FILENAME|  -  description
-                             -------------------
-    begin                : |DATE|
-    copyright            : (C) |YEAR| by |AUTHOR|
-    email                : |EMAIL|
- ***************************************************************************/
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,19 +9,20 @@
 
 #include "linpsk.h"
 
-
+#include "addrxwindow.h"
+#include "bpskmodulator.h"
 #include "controlpanel.h"
 #include "crxdisplay.h"
 #include "ctxdisplay.h"
 
 #include "parameter.h"
-#include "addrxwindow.h"
+
 #include "spectrumdisplay.h"
 #include "frequencyselect.h"
 #include "cledbutton.h"
 #include "rttymodulator.h"
 #include "pskmodulator.h"
-#include "bpskmodulator.h"
+#include "psk63modulator.h"
 #include "qpskmodulator.h"
 #include "mfskmodulator.h"
 #include "ctxbuffer.h"
@@ -42,21 +35,27 @@
 #include "modemenu.h"
 #include "addmacro.h"
 #include "deletemacro.h"
+#include "activatemacros.h"
 #include "qsodata.h"
 #include "editmacro.h"
 #include "deletemacro.h"
 #include "renamemacro.h"
 #include "color.h"
+#include "definebandlist.h"
+#ifdef WITH_HAMLIB
+#include "rigcontrol.h"
+#endif
+#include <unistd.h>
 
 
 #include <QtGui>
 #include <QEventLoop>
+#include <QMessageBox>
+#include <QFileDialog>
+#include <QFontDialog>
+#include <QColorDialog>
 
-#ifdef HAVE_CONFIG
-#include "config.h"
-#else
-#define VERSION "1.2"
-#endif
+#define VERSION "1.3.5"
 
 
 #define ProgramName "LinPSK "
@@ -67,17 +66,28 @@ extern Parameter settings;
  *  name 'name' and widget flags set to 'f'.
  *
  */
-LinPSK::LinPSK ( QWidget* parent, Qt::WFlags fl )
-  : QMainWindow ( parent, fl ), Ui::LinPSK()
+LinPSK::LinPSK ( QWidget* parent)
+  : QMainWindow ( parent), Ui::LinPSK()
 {
   Sound = 0;
   Modulator = 0;
   inAction=false;
+  // Content of modeList must correspond to enum Mode in constants.h
+  modeList << "BPSK31" << "BPSK63" << "QPSK" << "RTTY" << "MFSK16"   ;
+#ifdef WITH_HAMLIB
+  settings.rig =new RigControl();
+#endif
+  /** To avoid multipe Macro clicking **/
+  blockMacros=false;
+  /************************************/
   SaveParameters = new Parameter();
 
   setupUi(this);
   read_config();
-  Control->enableSaveData();
+  apply_settings();
+
+  /** Fixme: handle font change: fontChange() **/
+
   if ( settings.ApplicationFont == 0 )
   {
     settings.ApplicationFont = new QFont ( qApp->font().family() );
@@ -103,7 +113,53 @@ LinPSK::LinPSK ( QWidget* parent, Qt::WFlags fl )
   msg = new QLabel ( );
   statusbar->addPermanentWidget ( msg, 2 );
   msg->setText ( tr ( "Ready" ) );
+#ifdef WITH_HAMLIB
+  rigInfo =new QLabel();
+  statusbar->addPermanentWidget(rigInfo,1);
+  if((settings.rigModelNumber > 0) && settings.rigDevice != "None")
+    {
+     int rc=-settings.rig->connectRig();
+     if(rc != RIG_OK)
+       {
+         switch(rc) {
+           case RIG_EINVAL :
+             QMessageBox::warning(0,"Invalid parameter",QLatin1String("Probably unknown rig"));
+             rigInfo->setText("Rig: None");
+             break;
+           case RIG_ETIMEOUT:
+           default:
+             if(rc != RIG_ETIMEOUT)
+               QMessageBox::warning(0,"Connection time out",QLatin1String(rigerror(rc)));
+             if(QMessageBox::question ( 0,"Connection time out" , tr ( "Could not connect to rig\nTry again ?" ),
+                                        QMessageBox::Yes | QMessageBox::No ) == QMessageBox::Yes)
+               {
+                 rc=-settings.rig->connectRig();
+                 if( rc != RIG_OK)
+                   {
+                     QMessageBox::warning(0,"Connection time out",QLatin1String(rigerror(rc)));
+                     rigInfo->setText("Rig: None");
+                   }
+                 else
+                   rigInfo->setText(QLatin1String("Rig: ")+settings.rig->getModelName());
+               }
+             else
+              rigInfo->setText("Rig: None");
+             break;
 
+        }
+
+       }
+     else
+       {
+         rigInfo->setText(QLatin1String("Rig: ")+settings.rig->getModelName());
+       }
+     if( rc == RIG_OK)
+       {
+
+       }
+    }
+#endif
+  Control->initQsoData();
 // IMD
   IMD = new QLabel ( statusbar );
   statusbar -> addPermanentWidget ( IMD, 1 );
@@ -131,23 +187,18 @@ LinPSK::LinPSK ( QWidget* parent, Qt::WFlags fl )
 
   Control->setColorList ( &WindowColors );
   languageChange();
-
 // signals and slots connections
 //========== Macro Processing ======================================
-  tokenList << "@CALLSIGN@" << "@DATE@" << "@Replace by filename@" << "@RX@" << "@THEIRCALL@" << "@THEIRNAME@" << "@TIMELOCAL@" << "@TIMEUTC@" << "@TX@" << "@RSTGIVEN@" << "@RSTRCVD@";
+  tokenList << "@CALLSIGN@" << "@DATE@" << "@Replace by filename@" << "@RX@" << "@THEIRCALL@" << "@THEIRNAME@";
+  tokenList << "@TIMELOCAL@" << "@TIMEUTC@" << "@TX@" << "@RSTGIVEN@" << "@RSTRCVD@" <<"@TXPWR@";
   Control->insertMacros( &macroList );
-//  connect(Control,SIGNAL(executeMacro(int)),this,SLOT(executeMacro(int)));
-
   connect ( this, SIGNAL ( StartRx() ), this, SLOT ( startRx() ) );
   connect ( this, SIGNAL ( StartTx() ), this, SLOT ( startTx() ) );
 
 //===================================================================
 
   TxBuffer = new CTxBuffer();
-
-  apply_settings();
   TxDisplay->txWindow->setTxBuffer ( TxBuffer );
-
 }
 
 /*
@@ -210,7 +261,7 @@ void LinPSK::fileOpen()
 {
   QString fileName;
 
-  fileName = QFileDialog::getOpenFileName ( 0, tr ( "Open Demofile" ), "", settings.DemoModeFileType[settings.DemoTypeNumber] );
+  fileName = QFileDialog::getOpenFileName ( 0, tr ( "Open Demofile" ), "", "*.wav" );
   if ( !fileName.isEmpty() )
     settings.inputFilename = fileName;
 }
@@ -245,11 +296,10 @@ void LinPSK::helpAboutQt()
 
 void LinPSK::addRxWindow()
 {
-  AddRxWindow *Channel = new AddRxWindow();
+  AddRxWindow *Channel = new AddRxWindow(modeList);
   if ( Channel->exec() != 0 )
   {
     AfcMode modus;
-//    modus = RxDisplay->RxFreq->getAfcMode();
     modus = RxDisplay->getAfcMode();
     settings.ActChannel->setAfcMode ( modus );
     Mode rxmode = ( Mode ) Channel->selectedMode();
@@ -298,6 +348,7 @@ void LinPSK::startRx()
     TxBuffer->insert ( TXOFF_CODE );
     if ( Sound != NULL )  // Switch Trx to rx
       {
+        TxDisplay->switch2Rx();
         msg->setText ( tr ( "Switching to receive" ) );
         while ( Sound->isRunning() ) // Wait for buffer to be cleared
           qApp->processEvents ( QEventLoop::AllEvents, 100 );
@@ -305,37 +356,13 @@ void LinPSK::startRx()
   }
   if ( RxDisplay->start_process_loop() )
   {
-    QString Info;
     TxDisplay->TxFunctions->setStatus ( OFF );
     if ( settings.ActChannel != 0 )
-      switch ( settings.ActChannel->getModulationType() )
-      {
-        case QPSK:
-          Info = "QPSK";
-          break;
-
-        case BPSK:
-          Info = "BPSK";
-          break;
-
-        case RTTY:
-          Info = "RTTY";
-          break;
-
-        case MFSK16:
-          Info = "MFSK16";
-          break;
-
-
-        default:
-          Info = "undefined";
-      }
-
-    msg->setText ( tr ( "Receiving " ) + Info );
+      msg->setText ( tr ( "Receiving " ) + modeList[settings.ActChannel->getModulationType()] );
   }
   else
     TxDisplay->TxFunctions->setStatus ( UNDEF );
-  Control->display();
+  Control->present(true);
   settings.Status = TxDisplay->TxFunctions->getstatus();
   TxDisplay->txWindow->setFocus();
   inAction=false;
@@ -345,10 +372,8 @@ void LinPSK::startTx()
 {
   Mode ModulationType;
   QString errorstring;
-  QString Info;
   double Frequency;
 
-
   RxDisplay->stop_process_loop();
   if ( settings.ActChannel == 0 )
   {
@@ -364,37 +389,32 @@ void LinPSK::startTx()
   {
     case QPSK:
       Modulator = new QPskModulator ( 11025, Frequency, TxBuffer );
-      Info = "QPSK";
       break;
-    case BPSK:
-      Modulator = new BPSKModulator ( 11025, Frequency, TxBuffer );
-      Info = "BPSK";
+    case BPSK31:
+      Modulator = new BpskModulator ( 11025, Frequency, TxBuffer );
+      break;
+    case BPSK63:
+      Modulator = new Psk63Modulator ( 11025, Frequency, TxBuffer );
       break;
 
     case RTTY:
       Modulator = new RTTYModulator ( 11025, Frequency, TxBuffer );
       if ( settings.ActChannel->getParameter ( Extra ) != 0 )
         Modulator->setParameter ( Extra, settings.ActChannel->getParameter ( Extra ) );
-      Info = "RTTY";
       break;
     case MFSK16:
       Modulator = new MFSKModulator ( 11025, Frequency, TxBuffer );
-      Info = "MFSK16";
       break;
 
-    default:
-      Modulator = new BPSKModulator ( 11025, Frequency, TxBuffer );
-      Info = "BPSK";
-      break;
+/**    default:
+      Modulator = new BpskModulator ( 11025, Frequency, TxBuffer );
+      break; */
   }
   if ( Sound <= NULL ) // Only create Sound Device once for output
   {
     if ( settings.DemoMode )
     {
-      if ( settings.DemoTypeNumber == 0 )
-        Sound = new WaveInput ( -1 );
-      else
-        Sound = new TextInput ( -1 );
+      Sound = new WaveInput ( -1 );
       msg->setText ( tr ( "Transmitting (Demo)" ) );
     }
     else
@@ -412,15 +432,16 @@ void LinPSK::startTx()
   {
     QMessageBox::information ( 0, ProgramName, errorstring );
     stopTx();
+     emit  StartRx();
     return;
   }
 
   connect ( Modulator, SIGNAL ( charSend ( char ) ), settings.ActChannel, SLOT ( updateRx ( char ) ) );
   TxDisplay->TxFunctions->setStatus ( ON );
-  msg->setText ( tr ( "Transmitting " ) + Info );
+  msg->setText ( tr ( "Transmitting " ) + modeList[ModulationType] );
   TxDisplay->txWindow->setFocus();
   settings.Status = TxDisplay->TxFunctions->getstatus();
-  Control->undisplay();
+  Control->present(false);
 
   Txcount = BUF_SIZE;
 //  process_txdata(); // Generate first Sample
@@ -462,7 +483,35 @@ void LinPSK::generalSettings()
 {
   GeneralSettings *LocalSettings = new GeneralSettings ( this );
   if ( LocalSettings->exec() != 0 )
-    settings = LocalSettings->getSettings();
+    {
+      settings = LocalSettings->getSettings();
+#ifdef WITH_HAMLIB
+      int modelNr = settings.rigModelNumber;
+      if( (modelNr >0) && ((modelNr != settings.rigModelNumber) || !settings.rig->isConnected()) ) //Rig has changed
+        {
+          settings.rig->disconnectRig();
+          int rc = -settings.rig->connectRig();
+          if(rc != RIG_OK)
+            {
+              switch(rc) {
+                case RIG_ETIMEOUT:
+                  QMessageBox::warning(0,"Connection time out",QLatin1String("Could not connect to rig"));
+                  break;
+                case RIG_EINVAL :
+                  QMessageBox::warning(0,"Invalid parameter",QLatin1String("Probably unknown rig.\nTrying to keep previous one"));
+                  break;
+                default:
+                  QMessageBox::warning(0,"Connection time out",QLatin1String("Unknown reason"));
+                  break;
+
+             }
+              settings.rigModelNumber=modelNr; // Reconnect here ?
+              if(settings.rig->connectRig() != RIG_OK)
+                return;
+            }
+        }
+#endif
+    }
   apply_settings();
 }
 void LinPSK::chooseColor()
@@ -497,58 +546,40 @@ void LinPSK::FontSetup()
     qApp->setFont ( f );
   }
 }
+
 void LinPSK::stopTx()
 {
   Modulator->disconnect();
   if ( Sound != 0 )
   {
     Sound->PTT ( false );
+    Sound->wait();
     Sound->close_Device();
   }
   delete Modulator;
   Modulator = 0;
+  TxDisplay->txWindow->clearBuffers();
 }
 
 void LinPSK::apply_settings()
 {
-  selectPTTDevice();
+  checkControlDevices();
+  Control->enableSaveData();
+  Control->setAutoDate();
+  actionOpen_Demo_File->setEnabled(settings.DemoMode);
 }
 void LinPSK::setChannelParams()
 {
   Control->setPhasePointer ( settings.ActChannel->getPhasePointer() );
   Control->newChannel();
   if ( settings.ActChannel != 0 )
-  {
-    QString Info;
-    switch ( settings.ActChannel->getModulationType() )
-    {
-
-      case QPSK:
-        Info = "QPSK";
-        break;
-
-      case BPSK:
-        Info = "BPSK";
-        break;
-
-      case RTTY:
-        Info = "RTTY";
-        break;
-
-      case MFSK16:
-        Info = "MFSK16";
-        break;
-      default:
-        Info = "undefined";
-    }
+        msg->setText ( tr ( "Receiving " ) + modeList[settings.ActChannel->getModulationType()] );
     RxDisplay->setAfcProperties( settings.ActChannel->AfcProperties() );
-    msg->setText ( tr ( "Receiving " ) + Info );
-  }
 }
 void LinPSK::setRxMode()
 {
-  QString Info;
-  ModeMenu Menu ;
+
+  ModeMenu Menu(modeList) ;
   ExtraParameter *Param;
   ExtraParameter parameter;
 
@@ -560,39 +591,12 @@ void LinPSK::setRxMode()
     Mode rxmode = ( Mode ) Menu.selectedMode();
     settings.ActChannel->setMode ( rxmode );
     RxDisplay->setAfcProperties( settings.ActChannel->AfcProperties() );
-    RxDisplay->setAfc ( settings.ActChannel->getAfcMode() );
+//    RxDisplay->setAfc ( settings.ActChannel->getAfcMode() );
     Control->setPhasePointer ( settings.ActChannel->getPhasePointer() );
     parameter= Menu.getParameter();
     settings.ActChannel->setParameter ( Extra, &parameter );
+    msg->setText ( tr ( "Receiving " ) + modeList[rxmode] );
   }
-  if ( settings.ActChannel != 0 )
-    switch ( settings.ActChannel->getModulationType() )
-    {
-      case QPSK:
-        Info = "QPSK";
-        break;
-
-      case BPSK:
-        Info = "BPSK";
-        break;
-
-      case RTTY:
-        Info = "RTTY";
-        break;
-
-      case MFSK16:
-        Info = "MFSK16";
-        break;
-/* RIP 
-    case RTTY2:
-        Info = "RTTY2";
-        break;
-*/
-      default:
-        Info = "undefined";
-    }
-
-  msg->setText ( tr ( "Receiving " ) + Info );
 }
 
 void LinPSK::save_config()
@@ -601,9 +605,7 @@ void LinPSK::save_config()
   QSettings config ( "DL1KSV", "LinPSK" );
   /** Windows Parameter **/
   config.beginGroup ( "WindowsParameter" );
-// config.setValue ( "MinimumWindowWidth", settings.MinimumWindowWidth );
   config.setValue ( "WindowWidth", width() );
-// config.setValue ( "MinimumWindowHeight", settings.MinimumWindowHeight );
   config.setValue ( "Xpos", this->x() );
   config.setValue ( "Ypos", this->y() );
   config.setValue ( "WindowHeight", height() );
@@ -614,12 +616,9 @@ void LinPSK::save_config()
   config.endGroup();
   /** DemoMode **/
   config.setValue ( "DemoMode", settings.DemoMode );
-  config.setValue ( "DemoTypeNumber", settings.DemoTypeNumber );
 //Operating
   config.setValue ( "Callsign", settings.callsign );
   config.setValue ( "MyLocator", settings.myLocator );
-
-  config.setValue ( "PTTDevice", settings.SerialDevice );
 //Logging
   config.setValue ( "Directory", settings.Directory );
   config.setValue ( "QSoFileName", settings.QSOFileName );
@@ -635,6 +634,7 @@ void LinPSK::save_config()
   config.setValue ( "dateFormat", settings.dateFormat );
   config.setValue ( "Slashed0", settings.slashed0 );
   config.setValue ("autoCrLf",settings.autoCrLf);
+  config.setValue ("autoDate",settings.autoDate);
   /** Colors **/
   if ( WindowColors.size() > 0 )
   {
@@ -663,6 +663,30 @@ void LinPSK::save_config()
      }
      config.endArray();
    }
+  // Bandlist
+   size=settings.bandList.size();
+   if(size >0)
+     {
+       config.beginWriteArray ("Bandlist");
+       for(i=0;i < size;i++)
+         {
+           config.setArrayIndex ( i );
+           config.setValue ( "Bandname", settings.bandList.at( i ).bandName );
+           config.setValue ( "Bandstart", settings.bandList.at(i).bandStart );
+           config.setValue ( "Bandend", settings.bandList.at(i).bandEnd );
+           config.setValue ( "PreferedFrequency",settings.bandList.at(i).preferedFreq);
+
+         }
+       config.endArray();
+     }
+   // Rig parameter for use with hamlib
+     config.beginGroup ( "Rigparameter" );
+     config.setValue ( "PTTDevice", settings.SerialDevice );
+     config.setValue( "RIGDevice", settings.rigDevice);
+     config.setValue("Modelnr",settings.rigModelNumber);
+     config.setValue("BaudRate",settings.baudrate);
+     config.setValue("Handshake",settings.handshake);
+     config.endGroup();
 
   // SoundDevices
    config .beginGroup("SoundDevices");
@@ -676,6 +700,15 @@ void LinPSK::save_config()
 void LinPSK::executeMacro ( int id )
 {
 //  qDebug("Execute macro %d",id);
+  if(blockMacros) {
+    qDebug("Macro %d blocked",id);
+    return;
+  }
+  else
+  {
+    blockMacros=true;
+    QTimer::singleShot(1000,this,SLOT(unblockMacros()));
+  }
   QString macro = macroList.at(id).text;
   QString Token;
   QFile *MacroFile;
@@ -747,6 +780,18 @@ void LinPSK::executeMacro ( int id )
                                                  QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton );
                           return;
                         }
+                         if(settings.callsign.isEmpty())
+                         {
+                            QMessageBox::warning(0,"Parameter error",QLatin1String("Callsign not set"));
+                            TxDisplay->TxFunctions->setStatus ( OFF );
+                            return;
+                          }
+                         if(macro.contains(tokenList.at(4)) && settings.QslData->RemoteCallsign.isEmpty())  //Check if macro contains remote callsign when switching to tx
+                          {
+                            QMessageBox::critical(0,"Parameter error",QLatin1String("Remote callsign not set"));
+                            TxDisplay->TxFunctions->setStatus ( OFF );
+                            return;
+                          }
                         macro.remove ( indexvon, 4 );
                         if(settings.Status == OFF)
                           emit StartTx();
@@ -766,6 +811,13 @@ void LinPSK::executeMacro ( int id )
                            macro.replace ( indexvon, tokenList.at(10).length(),settings.QslData->HisRST );
 
                           }
+                          else
+                            if( Token == tokenList.at(11) )  // TXPWR
+                            {
+                             QString pwr;
+                             pwr.setNum(settings.pwr);
+                             macro.replace ( indexvon, tokenList.at(11).length(),pwr);
+                            }
                           else  // Must be File
                           {
                             macro.remove ( indexvon, Token.length() );
@@ -808,6 +860,7 @@ void LinPSK::executeMacro ( int id )
     TxDisplay->insert(macro);
     if(switchtoRx & (settings.Status == ON))
       {
+        TxDisplay->TxFunctions->setStatus(SW);
         msg->setText ( tr ( "Switching to receive" ) );
         emit  StartRx();
       }
@@ -839,6 +892,14 @@ void LinPSK::deleteMacro()
   }
   delete dL;
 }
+void LinPSK::actdeactMacros()
+{
+  ActivateMacros *act =new ActivateMacros(&macroList);
+  if(act->exec() !=0 ) {
+    Control->insertMacros( &macroList );
+  }
+  delete act;
+}
 void LinPSK::renameMacro()
 {
   RenameMacro *rM = new RenameMacro(&macroList);
@@ -880,12 +941,10 @@ void LinPSK::read_config()
   config.endGroup();
   /** DemoMode **/
   settings.DemoMode = config.value ( "DemoMode" ).toBool();
-  settings.DemoTypeNumber = config.value ( "DemoTypeNumber" ).toInt();
 //Operating
   settings.callsign = config.value ( "Callsign" ).toString();
   settings.myLocator = config.value ( "MyLocator" ).toString();
 
-  settings.SerialDevice = config.value ( "PTTDevice" ).toString();
 //Logging
   settings.Directory = config.value ( "Directory", QDir::homePath() ).toString();
 
@@ -901,6 +960,7 @@ void LinPSK::read_config()
   settings.dateFormat = config.value ( "dateFormat", "dd.MM.yyyy" ).toString();
   settings.slashed0 = config.value ( "Slashed0" ).toBool();
   settings.autoCrLf = config.value("autoCrLf").toBool();
+  settings.autoDate = config.value("autoDate").toBool();
   /** Colors **/
   if ( config.contains ( "Colors" ) )
   {
@@ -932,13 +992,47 @@ void LinPSK::read_config()
         }
     }
     config.endArray();
+// Bandlist
+    size = config.beginReadArray ("Bandlist");
 
+    if(size >0)
+      {
+        Band band;
+        for(i=0;i < size;i++)
+          {
+            config.setArrayIndex ( i );
+            band.bandName = config.value ( "Bandname" ).toString();
+            band.bandStart = config.value ( "Bandstart",1).toInt();
+            band.bandEnd = config.value ( "Bandend",1).toInt();
+            band.preferedFreq = config.value ( "PreferedFrequency",1).toInt();
+            settings.bandList.append(band);
+          }
+      }
+     else
+      {
+        Band none;
+        none.bandName   = "--";
+        none.bandStart  = 0;
+        none.bandEnd    = 60000000;
+        none.preferedFreq=0;
+        settings.bandList.append(none);
+      }
+     config.endArray();
 
  if ( ( HeighttoSet > 0 ) && ( WidthtoSet > 0 ) )
     resize ( WidthtoSet, HeighttoSet );
  if ( ( X >= 0 ) && ( Y >= 0 ) )
     move ( X, Y );
  // SoundDevices
+ // Rig parameter for use with hamlib
+   config.beginGroup ( "Rigparameter" );
+   settings.SerialDevice = config.value ( "PTTDevice" ).toString();
+   settings.rigDevice = config.value( "RIGDevice").toString();
+   settings.rigModelNumber = config.value("Modelnr",0).toInt();
+   settings.baudrate = config.value("BaudRate",9600).toInt();
+   settings.handshake= config.value("Handshake",1).toInt();
+   config.endGroup();
+
   config .beginGroup("SoundDevices");
   settings.InputDeviceName=config.value("InputDeviceName","LinPSK_Record").toString();
   settings.sampleRate=config.value("sampleRate",11025).toInt();
@@ -946,21 +1040,47 @@ void LinPSK::read_config()
   settings.complexFormat=config.value("ComplexFormat").toBool();
   config.endGroup();
 }
-void LinPSK::selectPTTDevice()
+void LinPSK::checkControlDevices()
 {
+  int  err = 0;
   settings.serial = -1;
+  int flags = TIOCM_RTS | TIOCM_DTR;
+
   if ( settings.SerialDevice != "None" )
   {
-    int flags = TIOCM_RTS | TIOCM_DTR;
-    settings.serial = open ( settings.SerialDevice.toAscii().data(), O_EXCL | O_WRONLY );
+    settings.serial = open( settings.SerialDevice.toLatin1().data(), O_EXCL | O_WRONLY );
     if ( settings.serial > 0 )
-      ioctl ( settings.serial, TIOCMBIC, &flags );
-    else
+      err=ioctl ( settings.serial, TIOCMBIC, &flags );
+    if( (settings.serial <0) || (err < 0 ))
     {
-      QMessageBox::critical ( 0, "LinPsk", "Unable to open Device " + settings.SerialDevice+"\nCheck permission of device" );
+      QMessageBox::critical ( 0, "LinPsk", "Unable to open PTT device " + settings.SerialDevice+"\nCheck if device is available or permission of device" );
       settings.SerialDevice = "None"; //Their seems to be a wrong Value in the ConfigFile
+      settings.serial=-1;
     }
    }
+#ifdef WITH_HAMLIB
+
+  if( (settings.SerialDevice != "None") && (settings.SerialDevice == settings.rigDevice))
+    {
+      QMessageBox::critical ( 0, "LinPsk", "PTT device and device to control the rig must be different\nPlease change configuration" );
+      settings.SerialDevice = "None";
+      settings.rigDevice="None";
+      return;
+    }
+  if ( settings.rigDevice != "None")
+  {
+    int fd = open( settings.rigDevice.toLatin1().data(), O_EXCL | O_WRONLY );
+    if ( fd > 0 )
+      err=ioctl ( fd, TIOCMBIC, &flags );
+    if( (fd <0) || (err < 0 ))
+    {
+      QMessageBox::critical ( 0, "LinPsk", "Unable to open serial port to control  rig" + settings.rigDevice+"\nCheck if device is available or permission of device" );
+      settings.rigDevice = "None"; //Their seems to be a wrong Value in the ConfigFile
+    }
+    if(fd >0)
+      ::close(fd);
+   }
+#endif      
 }
 
 
@@ -994,3 +1114,14 @@ void LinPSK::on_RxDisplay_newActiveChannel()
 {
 
 }
+void LinPSK::unblockMacros()
+{
+ blockMacros=false;
+}
+void LinPSK::defineBandlist()
+{
+  DefineBandList *dF = new DefineBandList();
+  if (dF->exec() != 0 )
+    Control->initQsoData();
+  delete dF;
+}
