@@ -1,11 +1,3 @@
-/***************************************************************************
-                          |FILENAME|  -  description
-                             -------------------
-    begin                : |DATE|
-    copyright            : (C) |YEAR| by |AUTHOR|
-    email                : |EMAIL|
- ***************************************************************************/
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,7 +34,7 @@ class LinPSK : public QMainWindow, private Ui::LinPSK
     Q_OBJECT
 
 public:
-    LinPSK( QWidget* parent = 0,Qt::WFlags fl = 0);
+    LinPSK( QWidget* parent = 0);
     ~LinPSK();
 
 
@@ -87,8 +79,12 @@ protected slots:
   void deleteMacro();
   /** Rename Macro **/
   void renameMacro();
+  /**Activate /Deactivate Macros**/
+  void actdeactMacros();
   /** Font Settings **/
   void FontSetup();
+  /** Define Bandlist **/
+  void defineBandlist();
   /** Save Settings **/
   void saveSettings();
   /** Closing this window **/
@@ -96,11 +92,13 @@ protected slots:
 
 private slots:
   void on_RxDisplay_newActiveChannel();
+  void unblockMacros();
 private:
 
     void read_config();
     void save_config();
     bool inAction;
+    bool blockMacros;
 Parameter *SaveParameters;    
 /** Modulator **/
 CModulator *Modulator;
@@ -114,10 +112,10 @@ unsigned int Txcount;
 Input *Sound;
 /** To show messages in Statusbar */
 QLabel *msg;
-/** TxTimer **/
-///QTimer *TxTimer;
-
-void selectPTTDevice();
+#ifdef WITH_HAMLIB
+QLabel *rigInfo;
+#endif
+void checkControlDevices();
 
 /** To show date and time **/
 QLabel *datum;
@@ -129,6 +127,8 @@ QList<QColor> WindowColors;
 /** Macros **/
 QVector<Macro> macroList;
 QStringList tokenList;
+/** Digital modes */
+QStringList modeList;
 
 signals:
 void StartRx();
