@@ -24,6 +24,9 @@
 #include "crxchannel.h"
 #include "processlogdata.h"
 #include "constants.h"
+#ifdef WITH_HAMLIB
+#include "rigcontrol.h"
+#endif
 
 #include <QDateTime>
 #include <QFile>
@@ -38,12 +41,12 @@ extern Parameter settings;
 QSOData::QSOData ( QWidget* parent )
     : QGroupBox ( parent ), Ui::QSOData()
 {
+  int i;
   setupUi ( this );
   QRegExp rx ( "^[A-R][A-R][0-9][0-9][A-X][A-X]$" );
   validator = new QRegExpValidator ( rx, this );
   Loc->setValidator ( validator );
   Loc->setStyleSheet ( "QLineEdit{color: black ; }" );
-  Distance->setAlignment ( Qt::AlignRight );
   QsoDate->setDisplayFormat ( settings.dateFormat );
   refreshDateTime();
   if ( settings.QslData )
@@ -52,7 +55,6 @@ QSOData::QSOData ( QWidget* parent )
     OpName->setText ( settings.QslData->OpName );
     Qth->setText ( settings.QslData->Qth );
     Loc->setText ( settings.QslData->Locator );
-    QsoFrequency->setCurrentIndex( settings.QslData->QsoFrequency );
     HisRST->setText ( settings.QslData->HisRST );
     MyRST->setText ( settings.QslData->MyRST );
     dokName->setText(settings.QslData->dokName);
@@ -62,6 +64,7 @@ QSOData::QSOData ( QWidget* parent )
   connect ( Clear, SIGNAL ( clicked() ), this, SLOT ( clear() ) );
   connect ( Qth, SIGNAL ( editingFinished () ), this, SLOT ( QTHchanged() ) );
   connect ( QsoFrequency, SIGNAL ( activated (int) ), this, SLOT ( frequencyChanged(int) ) );
+  connect ( txPwr,SIGNAL( valueChanged(int) ), this ,SLOT( pwrChanged(int) ) );
   connect ( MyRST, SIGNAL ( editingFinished () ), this, SLOT ( MyRSTchanged() ) );
   connect ( OpName, SIGNAL ( editingFinished () ), this, SLOT ( Namechanged() ) );
   connect ( Save, SIGNAL ( clicked() ), this, SLOT ( save() ) );
@@ -74,6 +77,13 @@ QSOData::QSOData ( QWidget* parent )
   connect ( RemoteCallsign, SIGNAL ( editingFinished ( ) ), this, SLOT ( sendRequest() ) );
   connect ( logBookCommunication, SIGNAL ( unabletoConnect() ), this , SLOT ( stopTrial() ) );
   connect ( logBookCommunication, SIGNAL ( answerAvailable() ), this, SLOT ( copyAnswer() ) );
+  //====== Control the rig ================================== //
+  for(i=0; i< settings.bandList.size(); i++)
+    QsoFrequency->addItem(settings.bandList.at(i).bandName);
+//  QsoFrequency->setCurrentIndex(findBand());
+
+//  txPwr->setValue(rigControl->get_pwr());
+
 }
 
 QSOData::~QSOData()
@@ -95,7 +105,11 @@ void QSOData::clear()
   settings.QslData->Qth = Qth->text();
   Loc->setText ( "" );
   settings.QslData->Locator = Loc->text();
-//QsoFrequency->setText ( "" );
+  QsoFrequency->setCurrentIndex(findBand());
+#ifdef WITH_HAMLIB
+  settings.pwr=settings.rig->get_pwr();
+  txPwr->setValue(settings.pwr);
+#endif
   settings.QslData->Locator = Loc->text();
   HisRST->setText ( "" );
   settings.QslData->HisRST = HisRST->text();
@@ -156,7 +170,10 @@ void QSOData::Locatorchanged()
 
 void QSOData::frequencyChanged(int index)
 {
-  settings.QslData->QsoFrequency = index;
+#ifdef WITH_HAMLIB
+  settings.rig->set_frequency(settings.bandList.at(index).preferedFreq);
+#endif
+  settings.QsoFrequency = index;
 }
 
 void QSOData::HisRSTchanged()
@@ -209,6 +226,8 @@ void QSOData::save()
   Locatorchanged();
   HisRSTchanged();
   MyRSTchanged();
+  if(settings.autoDate)
+    refreshDateTime();
   Datechanged();
   Timechanged();
   QString saveString, s;
@@ -241,6 +260,11 @@ void QSOData::save()
     s = QString ( "<BAND:%1>%2\n" ).arg ( QsoFrequency->currentText().length() ).arg ( QsoFrequency->currentText() );
     saveString.append ( s );
   }
+  // TxPwr
+  int pwr=txPwr->value();
+  s.setNum(pwr);
+  s = QString ("<TX_PWR:%1>%2\n").arg(s.length()).arg(s);
+  saveString.append(s);
   if ( QsoDate->text() == "" )
   {
     s = QString ( "<QSO_DATE:8:d>%1\n" ).arg ( QDateTime::currentDateTime().toString ( "yyyyMMdd" ) );
@@ -253,7 +277,8 @@ void QSOData::save()
   }
   if ( QsoTime->text() != "" )
   {
-    s = QString ( "<TIME_ON:%1>%2\n" ).arg ( QsoTime->text().length() ).arg ( QsoTime->text().remove ( ':' ) );
+    QString timeValue= QsoTime->text().remove ( ':' );
+    s = QString ( "<TIME_ON:%1>%2\n" ).arg ( timeValue.length() ).arg ( timeValue );
     saveString.append ( s );
   }
 
@@ -273,10 +298,14 @@ void QSOData::save()
     switch ( settings.ActChannel->getModulationType() )
     {
       case QPSK:
-      case BPSK:
+        s.append( "6>QPSK31");
+        break;
+      case BPSK31:
         s.append ( "5>PSK31\n" );
         break;
-
+      case BPSK63:
+        s.append ( "5>PSK63\n" );
+        break;
       case RTTY:
         s.append ( "4>RTTY\n" );
         break;
@@ -312,6 +341,11 @@ void QSOData::save()
   {
 
     saveString.append("<QSL_SENT:1>");
+    if(bureau->isChecked())
+       saveString.append("R\n");
+    else
+       saveString.append("N\n");
+    saveString.append("<QSL_RCVD:1>");
     if(bureau->isChecked())
        saveString.append("R\n");
     else
@@ -321,10 +355,22 @@ void QSOData::save()
        saveString.append("R\n");
      else
        saveString.append("N\n");
+    saveString.append("<EQSL_QSL_RCVD:1>");
+    if(eQsl->isChecked())
+       saveString.append("R\n");
+    else
+    saveString.append("N\n");
     saveString.append ( "<eor>\n" );
     if ( !logBookCommunication->isRunning() )
-      logBookCommunication->start();
+      {
+	logBookCommunication->start();
+#if QT_VERSION >= 0x050000
+        QThread::usleep(2000);
+#endif
+      }
+#ifndef QT_NO_DEBUG
     qDebug ( "Written to Logbook\n%s", qPrintable ( saveString ) );
+#endif
     logBookCommunication->saveQsoData ( saveString );
   }
 }
@@ -344,14 +390,14 @@ void QSOData::calculateDistance ( QString loc )
   mine = loc2coordinates ( settings.myLocator.constData() );
   his = loc2coordinates ( loc.constData() );
   dist = 6371. * acos ( sin ( mine.breite ) * sin ( his.breite ) + cos ( mine.breite ) * cos ( his.breite ) * cos ( mine.laenge - his.laenge ) );
-  Distance->setText ( s.arg ( ( int ) dist, 6 ) );
+  Distance->setText ( s.arg ( ( int ) dist, 5 ) );
 }
 QSOData::coordinates QSOData::loc2coordinates ( const QChar *l )
 {
   coordinates c;
-  c.laenge = ( 20. * ( l[0].toAscii() - 'A' ) + 2. * ( l[2].toAscii() - '0' ) + ( 1. / 12. ) * ( l[4].toAscii() - 'A' ) + 1. / 24. );
+  c.laenge = ( 20. * ( l[0].toLatin1() - 'A' ) + 2. * ( l[2].toLatin1() - '0' ) + ( 1. / 12. ) * ( l[4].toLatin1() - 'A' ) + 1. / 24. );
   c.laenge *= M_PI / 180.;
-  c.breite = 90. - ( 10. * ( l[1].toAscii() - 'A' ) + 1. * ( l[3].toAscii() - '0' ) + ( 1. / 24. ) * ( l[5].toAscii() - 'A' ) + 1. / 48. );
+  c.breite = 90. - ( 10. * ( l[1].toLatin1() - 'A' ) + 1. * ( l[3].toLatin1() - '0' ) + ( 1. / 24. ) * ( l[5].toLatin1() - 'A' ) + 1. / 48. );
   c.breite *= M_PI / 180.;
   return c;
 }
@@ -362,7 +408,7 @@ void QSOData::setQsoData(QsoData value,QString s)
   switch (value)
   {
     case CallSign :
-      RemoteCallsign->setText ( s );
+      RemoteCallsign->setText ( s.remove(QChar(' ')) );
       Callsignchanged();
       break;
     case QTH :
@@ -398,7 +444,6 @@ void QSOData::newChannel()
     Qth->setText ( settings.QslData->Qth );
     Loc->setText ( settings.QslData->Locator );
     Locatorchanged(); // Check Locator and set Color
-    QsoFrequency->setCurrentIndex ( settings.QslData->QsoFrequency );
     HisRST->setText ( settings.QslData->HisRST );
     MyRST->setText ( settings.QslData->MyRST );
     QsoDate->setDate ( settings.QslData->QsoDate );
@@ -434,8 +479,14 @@ void QSOData::sendRequest()
   results[4] = continent;
   results[5] = worked;
   if ( !logBookCommunication->isRunning() )
-    logBookCommunication->start();
-  logBookCommunication->requestCallSign ( results, RemoteCallsign->text().toUpper() );
+    {
+      logBookCommunication->start();
+#if QT_VERSION >= 0x050000
+      QThread::usleep(2000);
+#endif
+    }
+  logBookCommunication->requestCallsign ( results, RemoteCallsign->text().toUpper() );
+
 }
 void QSOData::stopTrial()
 {
@@ -450,3 +501,51 @@ void QSOData::copyAnswer()
   settings.QslData->continent = continent->text();
   settings.QslData->worked = worked->text();
 }
+void QSOData::setAutoDate()
+{
+  if(settings.autoDate)
+    {
+      dateLabel->hide();
+      QsoDate->hide();
+      timeLabel->hide();
+      QsoTime->hide();
+    }
+  else
+    {
+      dateLabel->show();
+      QsoDate->show();
+      timeLabel->show();
+      QsoTime->show();
+    }
+}
+void QSOData::pwrChanged(int p)
+{
+#ifdef WITH_HAMLIB
+  settings.rig->set_pwr(p);
+#endif
+  settings.pwr=p;
+}
+int QSOData::findBand()
+{
+#ifdef WITH_HAMLIB
+  int freq = settings.rig->get_frequency();
+  for(int i=0; i < settings.bandList.size();i++)
+    {
+      if( (settings.bandList.at(i).bandStart <= freq) && (settings.bandList.at(i).bandEnd >= freq))
+          return i;
+    }
+#endif
+  return settings.bandList.size()-1;
+}
+void QSOData::initQsoData()
+{
+  QsoFrequency->clear();
+  for(int i=0; i< settings.bandList.size(); i++)
+    QsoFrequency->addItem(settings.bandList.at(i).bandName);
+  QsoFrequency->setCurrentIndex(findBand());
+#ifdef WITH_HAMLIB
+  settings.pwr=settings.rig->get_pwr();
+#endif
+  txPwr->setValue(settings.pwr);
+
+}
