@@ -28,6 +28,8 @@
 class QChar;
 class ProcessLogData;
 class QValidator;
+class RigControl;
+
 class QSOData : public QGroupBox, private Ui::QSOData
 {
   Q_OBJECT
@@ -41,6 +43,8 @@ public:
   QSOData(QWidget* parent = 0);
   ~QSOData();
   void enableSaveData();
+  void setAutoDate();
+  void initQsoData();
 
 public slots:
   /*$PUBLIC_SLOTS$*/
@@ -61,7 +65,9 @@ public slots:
 
   void setQsoData(QsoData,QString);
   void newChannel();
+  void pwrChanged(int);
 
+signals:
 
 protected:
   coordinates loc2coordinates ( const QChar *l );
@@ -74,6 +80,9 @@ private:
   ProcessLogData *logBookCommunication;
   bool connectionError;
   QValidator *validator;
+
+  int findBand();
+
 };
 
 #endif
