@@ -29,13 +29,15 @@ extern Parameter settings;
 SpectrumDisplay::SpectrumDisplay ( QWidget* parent ) : QFrame ( parent ), Ui::SpectrumDisplay()
 {
   setupUi(this);
-  languageChange();
+  spectrumWindow->setDisplayRange(MinFreq->value(),MaxFreq->value());
   inputdata = 0;
   for(int i=0; i< fftsize;i++)
     smoothedfft[i]=0.;
   displayWidth=spectrumWindow->width()-2*spectrumWindow->frameWidth();
   connect(spectrumWindow,SIGNAL(frequencyChanged(double)),this ,SIGNAL(FrequencyChanged(double)));
   connect(waterfallWindow,SIGNAL(frequencyChanged(double)),this ,SIGNAL(FrequencyChanged(double)));
+  oldMinfreq=MinFreq->value();
+  oldMaxfreq=MaxFreq->value();
 }
 
 /*
@@ -43,23 +45,19 @@ SpectrumDisplay::SpectrumDisplay ( QWidget* parent ) : QFrame ( parent ), Ui::Sp
  */
 SpectrumDisplay::~SpectrumDisplay()
 {
-	// no need to delete child widgets, Qt does it all for us
+  // no need to delete child widgets, Qt does it all for us
 }
 
-/*
- *  Sets the strings of the subwidgets using the current
- *  language.
- */
 void SpectrumDisplay::resizeEvent ( QResizeEvent * )
 {
   if ( inputdata == 0 )
     return;          // No data available
   displayWidth=spectrumWindow->width()-2*spectrumWindow->frameWidth();
   if(fftsize < displayWidth)
-  {
-    qDebug("+++ SpectrumDisplay: Spectrum array %d lower than displaywidth %d",fftsize,displayWidth);
-    return;
-  }
+    {
+      qDebug("+++ SpectrumDisplay: Spectrum array %d lower than displaywidth %d",fftsize,displayWidth);
+      return;
+    }
   translate();
   calcFFT();
   spectrumWindow->plotSpectrum(false,fftdata, MinFreq->value(),MaxFreq->value());
@@ -71,21 +69,21 @@ void SpectrumDisplay::calcFFT()
   int i;
   float x,gain;
   if ( inputdata == 0 )
-     return;          // No data available
+    return;          // No data available
   if( Smooth->isChecked())
     {
       for ( i = 0;i < displayWidth;i++ )
-      {
-        if(inputdata[xtranslate[i]]> 0.02)
-           x=log10 ( inputdata[xtranslate[i]])+2;
+        {
+          if(inputdata[xtranslate[i]]> 0.02)
+            x=log10 ( inputdata[xtranslate[i]])+2;
           else
-           x=0.;
-        gain=(1. - exp(-(0.2 * x)));
-        smoothedfft[i]=smoothedfft[i]*(1.-gain) + gain *x;
-        fftdata[i] = smoothedfft[i];
-      }
-     }
-   else
+            x=0.;
+          gain=(1. - exp(-(0.2 * x)));
+          smoothedfft[i]=smoothedfft[i]*(1.-gain) + gain *x;
+          fftdata[i] = smoothedfft[i];
+        }
+    }
+  else
     {
       for ( i = 0;i < displayWidth;i++ )
         {
@@ -101,49 +99,51 @@ void SpectrumDisplay::calcFFT()
 
 void SpectrumDisplay::translate ( void )
 {
-    int i, to, minfreq, maxfreq,tmp;
-	minfreq = MinFreq->value();
-	maxfreq = MaxFreq->value();
-    to = int ( maxfreq * fftsize *4/ settings.sampleRate );
-    for ( i = 0;i < displayWidth;i++ )
+  int i, to, minfreq, maxfreq,tmp;
+  minfreq = MinFreq->value();
+  maxfreq = MaxFreq->value();
+  to = int ( maxfreq * fftsize *2/ settings.sampleRate );
+  for ( i = 0;i < displayWidth;i++ )
     {
       tmp= ( ( ( maxfreq - minfreq ) * i * to / displayWidth ) + minfreq * to ) / maxfreq;
       if( tmp < fftsize)
         xtranslate[i] = tmp;
       else
-      {
-        qDebug("+++ SpectrumDisplay: translation array size %d lower than requested size %d",fftsize,tmp);
-        return;
-      }
+        {
+          qDebug("+++ SpectrumDisplay: translation array size %d lower than requested size %d",fftsize,tmp);
+          return;
+        }
     }
 }
 
 void SpectrumDisplay::startPlot ( double *x, bool overload )
 {
-	inputdata = x;
-    int tmp=spectrumWindow->width()-2*spectrumWindow->frameWidth();
-    if( tmp != displayWidth)
+  inputdata = x;
+  int tmp=spectrumWindow->width()-2*spectrumWindow->frameWidth();
+  if( (tmp != displayWidth) || (oldMinfreq != MinFreq->value()) || (oldMaxfreq != MaxFreq->value()))
     {
       displayWidth=tmp;
+      oldMinfreq=MinFreq->value();
+      oldMaxfreq=MaxFreq->value();
       translate();
     }
-	calcFFT();
-    spectrumWindow->plotSpectrum(overload,fftdata, MinFreq->value(),MaxFreq->value());
-    waterfallWindow->plotWaterfall(fftdata);
+  calcFFT();
+  spectrumWindow->plotSpectrum(overload,fftdata, oldMinfreq,oldMaxfreq);
+  waterfallWindow->plotWaterfall(fftdata);
 }
 
 void SpectrumDisplay::setnewFrequency ( int position )
 {
 
-	double freq;
-    freq = ( position * ( MaxFreq->value() - MinFreq->value() ) ) / displayWidth + MinFreq->value();
-	settings.ActChannel->setRxFrequency ( freq );
-	emit FrequencyChanged ( freq );
+  double freq;
+  freq = ( position * ( MaxFreq->value() - MinFreq->value() ) ) / displayWidth + MinFreq->value();
+  settings.ActChannel->setRxFrequency ( freq );
+  emit FrequencyChanged ( freq );
 }
 
 void SpectrumDisplay::setPhasePointer ( std::complex<float> *p )
 {
-   spectrumWindow->setPhasePointer(p);
+  spectrumWindow->setPhasePointer(p);
 }
 void SpectrumDisplay::setColorList(QList<QColor> *c)
 {
@@ -151,9 +151,22 @@ void SpectrumDisplay::setColorList(QList<QColor> *c)
 }
 QByteArray SpectrumDisplay::spectrumSplitterState() const
 {
-   return spectrumSplitter->saveState();
+  return spectrumSplitter->saveState();
 }
 void SpectrumDisplay::restoreSplitterState(const QByteArray & spectrumState)
 {
   spectrumSplitter->restoreState(spectrumState);
 }
+void SpectrumDisplay::showSpectren(bool p)
+{
+  if(p)
+    {
+      spectrumWindow->show();
+      waterfallWindow->show();
+    }
+  else
+    {
+      spectrumWindow->hide();
+      waterfallWindow->hide();
+    }
+}
