@@ -30,7 +30,8 @@ class QWidget;
 /**
   *@author Volker Schroer
   */
-const int fftsize=1024; // Check size to protect arrays
+//const int fftsize=1024; // Check size to protect arrays
+const int fftsize=2048; // Check size to protect arrays
 
 class SpectrumDisplay : public QFrame , private Ui::SpectrumDisplay
 {
@@ -42,6 +43,7 @@ public:
   void setColorList(QList<QColor> *c);
   QByteArray spectrumSplitterState() const;
   void restoreSplitterState(const QByteArray & spectrumState);
+  void showSpectren(bool p);
 
 public slots:
   void startPlot(double *,bool);
