@@ -18,9 +18,10 @@
 
 CDemodulator::CDemodulator()
 {
-UseAfc = Off;
-Squelch = true;
-Threshold= 50;
+  UseAfc = Off;
+  Squelch = true;
+  Threshold= 50;
+  OszFrequency = 0.0;
 }
 
 CDemodulator::~CDemodulator()
@@ -31,7 +32,15 @@ void CDemodulator::setAfcMode(AfcMode afc) { UseAfc=afc; }
 
 void CDemodulator::setRxFrequency(double freq)
 {
-RxFrequency = freq;
+ if ( (freq > 200 ) && (freq < 3000 ) )
+  {
+    RxFrequency = freq;
+    OszFreqinc = freq*PI2/SampleRate;
+  }
+}
+complex<float> *CDemodulator::getPhasePointer()
+{
+  return NULL;
 }
 
 double CDemodulator::getRxFrequency(void)
@@ -57,10 +66,6 @@ bool CDemodulator::getSquelchState()
 {
 return Squelch;
 }
-std::complex<float> * CDemodulator::getPhasePointer()
-{
-return 0;
-}
 int CDemodulator::getThreshold()
 {
 return Threshold;
