@@ -19,10 +19,18 @@
 #define CONSTANTS_H
 
 #include <math.h>                        // for some constants like PI
-#include <QString>
 #include <QDate>
+#include <QString>
 #include <QTime>
 
+enum BUTTONSTATUS // Status of RX/TX Button
+{
+UNDEF,				// undefined
+ON,						// TX
+OFF,					// RX
+SW            // Switching to RX
+};
+
 #define TXOFF_CODE -1			// control codes that can be placed in the input
 #define TXON_CODE -2			// queue for various control functions
 #define TXTOG_CODE -3
@@ -40,11 +48,21 @@
 
 #define Ts (.032+.000000)			// Ts == symbol period(correct for +/- .23%error)
 #define M_PI_3_2	(M_PI_2+M_PI)		// 3Pi/2
-#define M_PI_3_4  (M_PI_2+M_PI_4) // 3Pi/4
+#define M_PI_3_4        (M_PI_2+M_PI_4) // 3Pi/4
 #define M_PI_5_4	(M_PI + M_PI_4) // 5Pi/4
 #define M_PI_7_4	(M_PI + M_PI_2 + M_PI_4) // 7Pi/4
 
-enum Mode {BPSK=0,QPSK,RTTY,MFSK16};
+#define PHASE_DISPLAY_BUFFER_LENGTH 12
+struct Band {
+  QString bandName;
+  int bandStart;
+  int bandEnd;
+  int preferedFreq;
+};
+
+enum Mode {BPSK31=0,BPSK63,QPSK,RTTY,MFSK16};
+
+
 enum AfcMode {Off,Narrow,Wide};
 
 enum Paritaet {None,Even,Odd};
@@ -79,7 +97,6 @@ typedef struct
  QString OpName;
  QString Qth;
  QString Locator;
- int QsoFrequency; // Number of item in QCombobox
  QString HisRST;
  QString MyRST;
  QDate QsoDate;
@@ -98,7 +115,7 @@ struct Macro {
   QString name;
   QString text;
   QString accelerator;
-  int languageType; // 0,1,2
+  int languageType; // 0,1,2 languageType-3 >> Macro is disabled
 };
 
 static const unsigned short int VARICODE_TABLE[] = {
