@@ -1,11 +1,3 @@
-/***************************************************************************
-                          crxchannel.cpp  -  description
-                             -------------------
-    begin                : Sam Jan 4 2003
-    copyright            : (C) 2003 by Volker Schroer
-    email                : dl1ksv@gmx.de
- ***************************************************************************/
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,6 +13,7 @@
 #include "crxwindow.h"
 #include "qpskdemodulator.h"
 #include "bpskdemodulator.h"
+#include "psk63demodulator.h"
 #include "rttydemodulator.h"
 #include "mfskdemodulator.h"
 #include "parameter.h"
@@ -43,6 +36,8 @@ CRxChannel::CRxChannel ( int ID, QWidget *parent, Mode DemodulatorType, unsigned
   {
     case QPSK:
       Demodulator = new QPskDemodulator();
+      SampleRate = 11025;
+      BufferLength = BUF_SIZE;
       break;
     case RTTY:
       Demodulator = new RTTYDemodulator();
@@ -54,13 +49,22 @@ CRxChannel::CRxChannel ( int ID, QWidget *parent, Mode DemodulatorType, unsigned
       SampleRate = 11025;
       BufferLength = BUF_SIZE;
       break;
-
-    default:
-      Demodulator = new BPskDemodulator();
+    case BPSK63:
+      Demodulator = new PSk63Demodulator();
+      SampleRate = 11025;
+      BufferLength = BUF_SIZE;
       break;
+    case BPSK31:
+      Demodulator = new BPskDemodulator();
+      SampleRate = 11025;
+      BufferLength = BUF_SIZE;
+      break;
+/**    default:
+      Demodulator = new BPskDemodulator();
+      break;*/
   }
   Demodulator->Init ( SampleRate, BufferLength ); // Should changed later to
-  // adjusted Samplerate
+                                                  // adjusted Samplerate
   Demodulator->setRxFrequency ( double ( Freq ) );
   Demodulator->setAfcMode ( Demodulator->AfcProperties() );
   RxWindow = new CRxWindow ( parent );
@@ -168,10 +172,7 @@ void CRxChannel::setPrevChannel ( CRxChannel *p )
 
 complex<float>* CRxChannel::getPhasePointer()
 {
-  if ( ( RxMode == BPSK ) || ( RxMode == QPSK ) )
-    return Demodulator->getPhasePointer();
-  else
-    return 0;
+  return Demodulator->getPhasePointer();
 }
 
 int CRxChannel::getID()
@@ -243,6 +244,8 @@ void CRxChannel::setMode ( Mode DemodulatorType )
     {
       case QPSK:
         Demodulator = new QPskDemodulator();
+        SampleRate = 11025;
+        BufferLength = BUF_SIZE;
         break;
       case RTTY:
         Demodulator = new RTTYDemodulator();
@@ -256,9 +259,21 @@ void CRxChannel::setMode ( Mode DemodulatorType )
         BufferLength = BUF_SIZE;
         break;
 
-      default:
-        Demodulator = new BPskDemodulator();
+      case BPSK63:
+        Demodulator = new PSk63Demodulator();
+        SampleRate = 11025;
+        BufferLength = BUF_SIZE;
         break;
+
+      case BPSK31:
+        Demodulator = new BPskDemodulator();
+        SampleRate = 11025;
+        BufferLength = BUF_SIZE;
+        break;
+
+/**      default:
+        Demodulator = new BPskDemodulator();
+        break; */
     }
     RxMode = DemodulatorType;
     Demodulator->Init ( SampleRate, BufferLength ); // Should changed later to
