@@ -1,11 +1,3 @@
-/***************************************************************************
-                          crxwindow.cpp  -  description
-                             -------------------
-    begin                : Mon Mar 6 2000
-    copyright            : (C) 2000 by Volker Schroer
-    email                : DL1KSV@gmx.de
- ***************************************************************************/
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,6 +10,8 @@
 #include <QLineEdit>
 #include <QFontMetrics>
 #include <QMenu>
+#include <QVBoxLayout>
+#include <QClipboard>
 
 #include "parameter.h"
 
@@ -33,16 +27,21 @@ CRxWindow::CRxWindow ( QWidget* parent )
   QFontMetrics fm ( font() );
   rowHeight = fm.height()+3;
   int pixelwidth=82*fm.width("A");
-  DisplayBox = new QWidget ( this );
+  DisplayBox = new QWidget ();
   DisplayBox-> setFocusPolicy( Qt::NoFocus);
-  DisplayBox->setFixedSize ( 642, RXWINDOWBUFFER*rowHeight );
+  DisplayBox->setGeometry( 0,0 ,pixelwidth, RXWINDOWBUFFER*rowHeight );
   DisplayBox->setContextMenuPolicy ( Qt::CustomContextMenu );
   connect ( DisplayBox, SIGNAL ( customContextMenuRequested ( QPoint ) ), this, SLOT ( contextMenu ( QPoint ) ) );
 
   setWidget ( DisplayBox );
+  linesLayout = new QVBoxLayout(DisplayBox);
+  linesLayout->setSpacing(0);
+  linesLayout->setContentsMargins(0, 0, 0, 0);
+  linesLayout->setObjectName(QString::fromUtf8("linesLayout"));
+  linesLayout->setSizeConstraint(QLayout::SetNoConstraint);
 
-//  setHorizontalScrollBarPolicy ( Qt::ScrollBarAsNeeded );
-  setHorizontalScrollBarPolicy ( Qt::ScrollBarAlwaysOff );
+
+  setHorizontalScrollBarPolicy ( Qt::ScrollBarAsNeeded );
   setVerticalScrollBarPolicy ( Qt::ScrollBarAlwaysOn );
 
   trigger = false;
@@ -53,19 +52,17 @@ CRxWindow::CRxWindow ( QWidget* parent )
   Row = 0;
   Column = 0;
   AutoScroll = true;
-  DisplayLineHeight = rowHeight - 1;
+
   for ( int i = 0;i < RXWINDOWBUFFER;i++ )
   {
 
     ScrollBuffer[i] = new QLineEdit ( DisplayBox );
     ScrollBuffer[i]->setFixedWidth(pixelwidth);
-    ScrollBuffer[i]->move ( 1, 1+ DisplayLineHeight*i );
-
+    ScrollBuffer[i]->setMaximumHeight(18);
     ScrollBuffer[i]->setFrame ( false );
     ScrollBuffer[i]->setReadOnly ( true );
-    ScrollBuffer[i]->setFixedHeight ( rowHeight );
+    linesLayout->addWidget(ScrollBuffer[i]);
     ScrollBuffer[i]->setContextMenuPolicy ( Qt::NoContextMenu );
-    ScrollBuffer[i]->show();
   }
   setBackgroundRole ( ScrollBuffer[0]->backgroundRole() );
   menu = new QMenu ( tr ( "Log value" ), DisplayBox );
@@ -81,9 +78,10 @@ CRxWindow::CRxWindow ( QWidget* parent )
   connect ( A, SIGNAL ( triggered() ), this, SLOT ( copyRST() ) );
   A = menu->addAction ("Dok");
   connect ( A, SIGNAL ( triggered() ), this, SLOT ( copyDok() ) );
+  A = menu->addAction ("Clipboard");
+  connect ( A, SIGNAL ( triggered() ), this, SLOT ( copy() ) );
 
   selectedString.clear();
-
 }
 
 /*
@@ -142,7 +140,7 @@ void CRxWindow::updateRx ( char c )
           }
         }
       }
-      QString s = ScrollBuffer[Row]->text() + QString ( QChar ( c ) );
+      QString s = ScrollBuffer[Row]->text() + QString ( QLatin1Char ( c ) );
       ScrollBuffer[Row]->setText ( s );
       Column++;
 
@@ -196,13 +194,17 @@ void CRxWindow::setColor ( QColor color )
   for ( int i = 0;i < RXWINDOWBUFFER;i++ )
     ScrollBuffer[i]->setStyleSheet ( "QLineEdit{color: " + color.name() + "; }" );
 }
-
+/**
 void CRxWindow::fontChange ( const QFont & )
 {
   QFontMetrics fm ( font() );
+  int pixelwidth=82*fm.width("A");
   for ( int i = 0;i < RXWINDOWBUFFER;i++ )
-    ScrollBuffer[i]->setFixedHeight ( fm.height() );
+    ScrollBuffer[i]->setFixedWidth( pixelwidth );
+  DisplayLineHeight = ScrollBuffer[0]->height()-1;
+
 }
+**/
 void CRxWindow::activateTrigger ( QString s )
 {
   trigger = true;
@@ -249,24 +251,38 @@ bool CRxWindow::getRecordingState()
   return save;
 }
 
-void CRxWindow::resizeEvent ( QResizeEvent * )
-{
-  int width = this->width();
-  DisplayBox->setFixedWidth ( width );;
-  for ( int i = 0;i < RXWINDOWBUFFER;i++ )
-    ScrollBuffer[i]->setFixedWidth ( width );
-}
+
 void CRxWindow::contextMenu ( QPoint p )
 {
   int selectedLine, selectedColumn;
   char c = 0xF8;
   QPoint p1 = QCursor::pos();
-  selectedLine = p.y() / DisplayLineHeight;
+//  selectedLine = (p.y()-3) / (ScrollBuffer[0]->height()-1);
+  selectedLine = p.y() / ScrollBuffer[0]->height();
+
+#ifndef QT_NO_DEBUG
+  qDebug("Line %d selected, lineheight, %d ",selectedLine,ScrollBuffer[0]->height());
+  qDebug("*****Cursor: x: %i y: %i",p.x(),p.y());
+  int start;
+  start=selectedLine-4;
+  if(start <0)
+    start=0;
+  for(int i=start;i <=selectedLine;i++)
+    {
+      qDebug("Zeile: %i, %s",i,qPrintable(ScrollBuffer[i]->text()));
+    }
+  qDebug("***Menuposition x: %i y: %i",p1.x(),p1.y());
+#endif
+
   if(selectedLine >= RXWINDOWBUFFER)
     selectedLine=RXWINDOWBUFFER-1;
-  selectedColumn = ScrollBuffer[selectedLine]->cursorPositionAt ( QPoint ( p.x(), 2 ) );
-  ScrollBuffer[selectedLine]->setCursorPosition ( selectedColumn );
-  ScrollBuffer[selectedLine]->cursorWordForward ( true );
+  selectedColumn=0;
+  if(!ScrollBuffer[selectedLine]->hasSelectedText())
+    {
+      selectedColumn = ScrollBuffer[selectedLine]->cursorPositionAt ( QPoint ( p.x(), 2 ) );
+      ScrollBuffer[selectedLine]->setCursorPosition ( selectedColumn );
+      ScrollBuffer[selectedLine]->cursorWordForward ( true );
+    }
   selectedString = ScrollBuffer[selectedLine]->selectedText();
   if(!selectedString.endsWith(QChar(' ')))
   {
@@ -285,7 +301,10 @@ void CRxWindow::contextMenu ( QPoint p )
     ScrollBuffer[selectedLine]->cursorWordForward ( true );
     selectedString = ScrollBuffer[selectedLine]->selectedText();
   }
+
+
   menu->exec ( p1 );
+  ScrollBuffer[selectedLine]->deselect();
 }
 void CRxWindow::copyCallSign()
 {
@@ -311,3 +330,7 @@ void CRxWindow::copyDok()
 {
   emit setQsoData( DOK, selectedString );
 }
+void CRxWindow::copy()
+{
+  QApplication::clipboard()->setText(selectedString);
+}
