@@ -21,6 +21,54 @@
 
 using namespace std;
 extern Parameter settings;
+#ifdef SOUND_DEBUG
+static snd_pcm_format_t format_types[] = {
+  // SND_PCM_FORMAT_UNKNOWN,
+  SND_PCM_FORMAT_S8,
+  SND_PCM_FORMAT_U8,
+  SND_PCM_FORMAT_S16_LE,
+  SND_PCM_FORMAT_S16_BE,
+  SND_PCM_FORMAT_U16_LE,
+  SND_PCM_FORMAT_U16_BE,
+  SND_PCM_FORMAT_S24_LE,
+  SND_PCM_FORMAT_S24_BE,
+  SND_PCM_FORMAT_U24_LE,
+  SND_PCM_FORMAT_U24_BE,
+  SND_PCM_FORMAT_S32_LE,
+  SND_PCM_FORMAT_S32_BE,
+  SND_PCM_FORMAT_U32_LE,
+  SND_PCM_FORMAT_U32_BE,
+  SND_PCM_FORMAT_FLOAT_LE,
+  SND_PCM_FORMAT_FLOAT_BE,
+  SND_PCM_FORMAT_FLOAT64_LE,
+  SND_PCM_FORMAT_FLOAT64_BE,
+  SND_PCM_FORMAT_IEC958_SUBFRAME_LE,
+  SND_PCM_FORMAT_IEC958_SUBFRAME_BE,
+  SND_PCM_FORMAT_MU_LAW,
+  SND_PCM_FORMAT_A_LAW,
+  SND_PCM_FORMAT_IMA_ADPCM,
+  SND_PCM_FORMAT_MPEG,
+  SND_PCM_FORMAT_GSM,
+  SND_PCM_FORMAT_SPECIAL,
+  SND_PCM_FORMAT_S24_3LE,
+  SND_PCM_FORMAT_S24_3BE,
+  SND_PCM_FORMAT_U24_3LE,
+  SND_PCM_FORMAT_U24_3BE,
+  SND_PCM_FORMAT_S20_3LE,
+  SND_PCM_FORMAT_S20_3BE,
+  SND_PCM_FORMAT_U20_3LE,
+  SND_PCM_FORMAT_U20_3BE,
+  SND_PCM_FORMAT_S18_3LE,
+  SND_PCM_FORMAT_S18_3BE,
+  SND_PCM_FORMAT_U18_3LE,
+  SND_PCM_FORMAT_U18_3BE
+};
+static unsigned int test_rates[] = {
+  8000, 11025, 16000, 22050, 32000, 44100, 48000, 96000, 192000
+};
+
+#define NELEMS(x) (sizeof(x)/sizeof(x[0]))
+#endif
 CSound::CSound ( int ptt = -1 ) : Input ( ptt )
 {
   started = false;
@@ -29,6 +77,7 @@ CSound::CSound ( int ptt = -1 ) : Input ( ptt )
   available = 0;
   readPointer = 0;
   free = 2 * BUF_SIZE;
+  handle=0;
 
 }
 CSound::~CSound()
@@ -76,7 +125,7 @@ bool CSound::open_Device_read ( QString *errorstring )
   }
   else
    device=settings.InputDeviceName;
-  err = snd_pcm_open ( &handle, device.toAscii(), SND_PCM_STREAM_CAPTURE, SND_PCM_ASYNC );
+  err = snd_pcm_open ( &handle, device.toLatin1(), SND_PCM_STREAM_CAPTURE, SND_PCM_ASYNC );
 
   if ( err < 0 )
   {
@@ -93,6 +142,9 @@ bool CSound::open_Device_read ( QString *errorstring )
     *errorstring = QString ( "Broken configuration : no configurations available: " ) + QString ( snd_strerror ( err ) );
     return false;
   }
+  #ifdef SOUND_DEBUG
+  dump_hw_params(handle,hwparams);
+  #endif
   /* Set the interleaved read/write format */
   err = snd_pcm_hw_params_set_access ( handle, hwparams, SND_PCM_ACCESS_RW_INTERLEAVED );
   if ( err < 0 )
@@ -102,6 +154,7 @@ bool CSound::open_Device_read ( QString *errorstring )
   }
   /* Set the sample format */
   err = snd_pcm_hw_params_set_format ( handle, hwparams, SND_PCM_FORMAT_FLOAT_LE );
+//  err = snd_pcm_hw_params_set_format ( handle, hwparams, SND_PCM_FORMAT_S32_LE );
   if ( err < 0 )
   {
     *errorstring = QString ( "Sample format Float not available : " ) + QString ( snd_strerror ( err ) );
@@ -139,6 +192,9 @@ bool CSound::open_Device_read ( QString *errorstring )
   if ( err < 0 )
   {
     *errorstring = QString ( "Unable to set hw params for input: " ) + QString ( snd_strerror ( err ) );
+    #ifdef SOUND_DEBUG
+    dump_hw_params(handle,hwparams);
+    #endif
     return false;
   }
   snd_pcm_hw_params_free ( hwparams );
@@ -201,7 +257,7 @@ bool CSound::open_Device_write ( QString *errorstring )
   }
   else
    device=settings.OutputDeviceName;
-  err = snd_pcm_open ( &handle, device.toAscii(), SND_PCM_STREAM_PLAYBACK, 0 );
+  err = snd_pcm_open ( &handle, device.toLatin1(), SND_PCM_STREAM_PLAYBACK, 0 );
   if ( err < 0 )
   {
       *errorstring = QString ( "Unable to open Device: " )+settings.OutputDeviceName+ QString(" ") + QString ( snd_strerror ( err ) );
@@ -268,7 +324,7 @@ bool CSound::open_Device_write ( QString *errorstring )
   err = snd_pcm_hw_params ( handle, hwparams );
   if ( err < 0 )
   {
-    *errorstring = QString ( "Unable to set hw params for input: " ) + QString ( snd_strerror ( err ) );
+    *errorstring = QString ( "Unable to set hw params for Output: " ) + QString ( snd_strerror ( err ) );
     return false;
   }
   snd_pcm_hw_params_free ( hwparams );
@@ -373,7 +429,7 @@ void CSound::PTT ( bool mode )
 
 bool CSound::close_Device()
 {
-  wait();
+//  wait();
   if ( handle != 0 )
     snd_pcm_close ( handle );
   handle = 0;
@@ -425,6 +481,12 @@ void CSound::record()
       if ( available >= BUF_SIZE )
         emit samplesAvailable();
     }
+    else if ( err > 0)
+      {
+        qDebug("Strange situation, only %d bytes read\nRetry",err);
+        snd_pcm_prepare ( handle );
+        snd_pcm_start ( handle );
+      }
     else
     {
       if ( err == -EPIPE )
@@ -458,7 +520,7 @@ void CSound::play()
   toBePlayed = 0;
   qDebug ( "Play thread started" );
 
-  while ( started )
+  while ( started || (!started && (toBePlayed >0))) // We should flush the buffer
   {
     LockPointers.lock();
     if ( toBePlayed <= BUF_SIZE && ( !signaled ) )
@@ -466,16 +528,9 @@ void CSound::play()
       emit samplesAvailable();
       signaled = true;
     }
-//    if ( free > ( 2* BUF_SIZE ) )
-//      qDebug ( "Out of bounds" );
     while ( toBePlayed < laenge && started )
       WakeUp.wait ( &LockPointers );
     LockPointers.unlock();
-    if ( !started )
-    {
- //     qDebug ( "Stop received" );
-      break;
-    }
     if ( toBePlayed >= BUF_SIZE )
       signaled = false;
     for ( int i = 0;i < laenge;i++ )
@@ -516,7 +571,7 @@ void CSound::play()
 
     }
   }
-  snd_pcm_drop ( handle );
+  snd_pcm_drain ( handle );
   qDebug ( "Play Thread terminated" );
 }
 int CSound::getDeviceNumber(QString device)
@@ -530,9 +585,32 @@ int CSound::getDeviceNumber(QString device)
           getline (cards, line);
           if ( line.find( device.toStdString() ) != std::string::npos )  {
               std::istringstream( line ) >>id;
+              cards.close();
               return id;
           }
       }
   }
+  cards.close();
   return id;
 }
+#ifdef SOUND_DEBUG
+void CSound::dump_hw_params(snd_pcm_t *h,snd_pcm_hw_params_t* hw_p)
+{
+ unsigned int i;
+ qDebug("PCM name: %s\n", snd_pcm_name (h));
+ qDebug("Formats:\n");
+
+ for (i = 0; i < NELEMS (format_types); i++){
+   snd_pcm_format_t    ft = format_types[i];
+  if (snd_pcm_hw_params_test_format (h, hw_p, ft) == 0)
+       qDebug( "    %-20s YES", snd_pcm_format_name (ft));
+   }
+
+ qDebug("Sample Rates:\n");
+  for (i = 0; i < NELEMS (test_rates); i++){
+    unsigned int rate = test_rates[i];
+    qDebug( "    %6u  %s", rate,
+             snd_pcm_hw_params_test_rate (h, hw_p, rate, 0) == 0 ? "YES" : "NO");
+  }
+}
+#endif
