@@ -1,18 +1,9 @@
-/***************************************************************************
-                          fskmodulator.h  -  description
-                             -------------------
-    begin                : Sam Mr 1 2003
-    copyright            : (C) 2003 by Volker Schroer
-    email                : dl1ksv@gmx.de
- ***************************************************************************/
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
- *   The PSK part is based on WinPSK 1.0 by Moe Wheatley, AE4JY            *
  ***************************************************************************/
 
 #ifndef FSKMODULATOR_H
@@ -20,9 +11,6 @@
 
 #include "cmodulator.h"
 
-/**
-  *@author Volker Schroer
-  */
 
 class FSKModulator : public CModulator  {
 public: 
@@ -32,8 +20,7 @@ public:
 protected:
 virtual int getToneNumber()=0;
 unsigned int NumberofTones;
-//double *ToneFrequencyr;
-//double *ToneFrequencyi;
+
 double ToneFrequencyr[16];
 double ToneFrequencyi[16];
 double Frequencyr,Frequencyi;
