@@ -23,7 +23,7 @@
 
 #define NumberofTones 16
 
-const double MFSKDistance ( double *xa, int b )
+double MFSKDistance ( double *xa, int b )
 {
 	double dist;
 	int a1, a2;
@@ -62,7 +62,7 @@ int MFSKDemodulator::getSquelchValue()
 
 	return 0;
 }
-bool MFSKDemodulator::Init ( double FS, int NumberofSamples )
+void MFSKDemodulator::Init( double FS, int NumberofSamples )
 {
 	int i;
 	NxSamples = NumberofSamples;
@@ -79,8 +79,6 @@ bool MFSKDemodulator::Init ( double FS, int NumberofSamples )
 		delayLine[i] = complex<double> ( 0.0, 0.0 );
 	for ( i = 0; i < RESOLUTION;i++ )
 		twiddles[i] = complex<double> ( cos ( i *  M_PI / RESOLUTION ), - sin ( i  * M_PI / RESOLUTION ) );
-
-	return true;
 }
 
 
@@ -174,7 +172,7 @@ void MFSKDemodulator::bitEstimate()
 	double max ;
 	int j, k, freq, pos;
 	double softBits[4];;
-
+	freq=pos=0;
 // Now we do some sliding fft on the downsampled values
 	for ( int i = 0;i < DOWNSAMPLEDBUFFERLENGTH;i++ )
 	{
