@@ -18,69 +18,67 @@
 #ifndef MFSKDEMODULATOR_H
 #define MFSKDEMODULATOR_H
 
-#include "fskdemodulator.h"
+#include "cdemodulator.h"
 #include <complex>
 #include <vector>
-#include "deinterleaver.h"
+
 using namespace std;
-//class Deinterleaver;
+class Deinterleaver;
 class Viterbi;
 class MFSKVaricode;
 /**
   *@author Volker Schroer
   */
-static char GraydecodeTable[16][4]={ {'0','0','0','0'}, //  0
-                              {'0','0','0','1'}, //  1
-			      {'0','0','1','1'}, //  2
-			      {'0','0','1','0'}, //  3
-			      {'0','1','1','0'}, //  4
-			      {'0','1','1','1'}, //  5
-			      {'0','1','0','1'}, //  6
-			      {'0','1','0','0'}, //  7
-			      {'1','1','0','0'}, //  8
-			      {'1','1','0','1'}, //  9
-			      {'1','1','1','1'}, // 10
-			      {'1','1','1','0'}, // 11
-			      {'1','0','1','0'}, // 12
-			      {'1','0','1','1'}, // 13
-			      {'1','0','0','1'}, // 14
-			      {'1','0','0','1'}  // 15
-};
-class MFSKDemodulator : public FSKDemodulator  {
+
+#define DOWNSAMPLEDBUFFERLENGTH 256 // 4096 /16
+#define DOWNRATE 16
+#define DELAY 44 // = Samplerate / DOWNRATE /BAUDRATE = 11025/16/15.625
+#define RESOLUTION 88 // 88 = 2* DELAY
+
+//class MFSKDemodulator : public FSKDemodulator  {
+class MFSKDemodulator : public CDemodulator  {
 public: 
   MFSKDemodulator();
   ~MFSKDemodulator();
- /** Prozess the input */
- void ProcessInput(double * input,double *);
- int getSquelchValue();
- bool Init(double,int);
- virtual double get2RxFrequency();
-
+	/** Prozess the input */
+	void ProcessInput(double * input,double *);
+  int getSquelchValue();
+  void Init(double,int);
+  virtual double get2RxFrequency();
 private:
+AfcMode AfcProperties();
+void mixdown(double *);
+void calcSoftBits(int pos, double *softBits);
+
+	unsigned int datashreg;
 
 MFSKVaricode *Decoder;
-//Deinterleaver leave0,leave1,leave2,leave3,leave4,
-//leave5,leave6,leave7,leave8,leave9;
 
-Deinterleaver leave[10];
+Deinterleaver * leave;
+complex<double> *history;
 Viterbi * viterbi;
-void decodesymbol(double *,unsigned char *);
+void sfft(complex<double>);
+void bitEstimate();
+void afc(int,double);
 void recvbit(int);
-void synchronize();
-void afc();
-AfcMode AfcProperties();
-unsigned int Bitshiftregister;
-
-public slots: // Public slots
-/** Set RxFrequencies for MFSK16 */
- void setRxFrequency(double);
-
+int processPtr,bitEstimatePtr,syncPtr,oscPos;
+/******************************/
+/** coeficients for slidding fft */
+complex<double> twiddles[RESOLUTION];;
+complex<double> downBuffer[DOWNSAMPLEDBUFFERLENGTH];
+complex<double> delayLine[DELAY];
+double energy[48][DELAY];
 
 inline unsigned char graydecode(unsigned char data)
 {
 	return data ^ (data >> 1);
 }
-
+inline unsigned char clamp(double x)
+{
+	return (x < 0) ? 0 : ((x > 255) ? 255 :(unsigned char) x);
+}
+public slots:
+void setRxFrequency(double);
 };
 
 #endif
