@@ -24,10 +24,6 @@ Status = UNDEF;
 
 // Defaultsettings
 
-//MinimumWindowWidth=640;
-//MinimumWindowHeight=480;
-
-
 callsign="";
 QslData=0;
 
@@ -38,15 +34,15 @@ QSOFileName="QSOData.adif";
 timeoffset=-2;
 
 DemoMode=true;
-DemoModeFileType[0]="*.wav";
-DemoModeFileType[1]="*.out";
-DemoTypeNumber=0;
+
 slashed0=false;
+autoCrLf=true;
+autoDate=true;
+
 RxChannels=1;
 ActChannel = 0;   // Pointer to the active Channel
 ChannelChain = 0; // Pointer to the Start of the Rx - ChannelChain
 ApplicationFont =0;
-autoCrLf=true;
 dateFormat="dd.MM.yyyy";
 
 InputDeviceName="LinPSK_Record";
@@ -56,6 +52,18 @@ complexFormat=false;
 LangName[0]="B";
 LangName[1]="E";
 LangName[2]="G";
+
+/** Rig **/
+rigModelNumber=0; // No rig
+#ifdef WITH_HAMLIB
+rig=0;
+#endif
+rigDevice="none";
+QsoFrequency=-1;
+pwr=5;
+handshake=1; // hardware
+baudrate=9600;
+
 }
 Parameter::~Parameter()
 {
