@@ -1,11 +1,3 @@
-/***************************************************************************
-                          qpskdemodulator.cpp  -  description
-                             -------------------
-    begin                : Sat Jun 2 2001
-    copyright            : (C) 2001 by Volker Schroer
-    email                : dl1ksv@gmx.de
- ***************************************************************************/
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,19 +7,16 @@
  *    based on the work of  Moe Wheatly, AE4JY                             *  
  ***************************************************************************/
 
+#include "firfilter.h"
 #include "qpskdemodulator.h"
 #include "viterbi.h"
 
 // phase wraparound correction table for viterbi decoder
-//static const double AngleTbl1[4] = { M_PI_3_2, 0.0, M_PI/2.0, M_PI};
-//static const double AngleTbl2[4] = { M_PI_3_2, PI2, M_PI/2.0, M_PI};
-//static const double AngleTbl1[4] = {  M_PI_2, -M_PI, -M_PI_2,0.0};
-//static const double AngleTbl2[4] = {  M_PI_2, M_PI, M_PI_3_2,0.0};
 static const double AngleTbl1[4] = {  0.0, -M_PI_2, -M_PI,-M_PI_3_2};
 static const double AngleTbl2[4] = {  0.0, M_PI_3_2, M_PI,M_PI_2};
 
 
-static const double  qdistance(double *x,int i)
+static double  qdistance(double *x,int i)
 {
 
 const double *pAngle;
@@ -55,6 +44,10 @@ v=new Viterbi(5,0x19,0x17,qdistance);
 }
 QPskDemodulator::~QPskDemodulator()
 {
+  if( downFilter )
+    delete downFilter;
+  if ( syncFilter )
+    delete syncFilter;
 }
 void QPskDemodulator::DecodeSymbol(double angle)
 
@@ -111,15 +104,6 @@ char ch =0;
 
 }
 
-//////////////////////////////////////////////////////////////////////
-// Calculate signal quality based on the statistics of the phase
-//	difference angle.  The more dispersion of the "0" and "180" degree
-//  phase shifts, the worse the signal quality.  This information is used
-//  to activate the squelch control.  If 20 consecutive "180" degree shifts
-//  occur, the squelch is forced on, and if 20 consecutive "0" degree
-//  shifts occur, the squelch is forced off quickly.
-//////////////////////////////////////////////////////////////////////
-
 void QPskDemodulator::CalcQuality(  double angle )
 {
 
@@ -138,7 +122,6 @@ else
  }
 if ( angle < 0.0 )
  temp = -temp;
-m_QFreqError = temp;
 temp = fabs(temp);
 
  
@@ -153,4 +136,28 @@ m_DevAve = 100. -m_DevAve *110.;
 
 }
 
+void QPskDemodulator::Init(double Fs ,int BlockSize)
+{
+  SampleRate = Fs;        //sample rate
+  NxSamples = BlockSize;  //size data input buffer
+  downFilter = new FIRFilter(PI2*31.25/Fs,79,ComplexData,10.);
+  syncFilter = new FIRFilter(PI2*31.25*18./Fs,79, ComplexData,5.);
+  downRate = 18;
 
+}
+double QPskDemodulator::calcFreqError(complex<double> s)
+{
+ double x,y;
+ complex<double> z;
+ if (abs(s) >1 )
+  z=s/abs(s);
+ else z=s;
+ x= z.real()*z.imag();
+ x /=5000.; // Adopt deviation to samplerate
+// x /=2.8016548; //Gain
+ y=x_loop_1+x +0.2861361823*y_loop_1;
+ x_loop_1=x;
+ y_loop_1=y;
+ return -y;
+
+}
