@@ -33,6 +33,11 @@ SpectrumWindow::SpectrumWindow(QWidget *parent) :
   pdisplay->fill();
   Farbe=0;
 }
+void SpectrumWindow::setDisplayRange(int minfreq, int maxfreq)
+{
+  minDisplayfrequency=minfreq;
+  maxDisplayfrequency=maxfreq;
+}
 void SpectrumWindow::resizeEvent(QResizeEvent *)
 {
   int x=2*frameWidth();
@@ -41,7 +46,7 @@ void SpectrumWindow::resizeEvent(QResizeEvent *)
   pdisplay =new QPixmap (this->width()-x,this->height()-x);
   pdisplay->fill();
   QPainter p(pdisplay);
-  paintLineal(&p,pdisplay->width(),pdisplay->height(),100,2500);
+  paintLineal(&p,pdisplay->width(),pdisplay->height(),minDisplayfrequency,maxDisplayfrequency);
   p.end();
 }
 
@@ -117,7 +122,7 @@ void SpectrumWindow::plotSpectrum(bool overload,float *fftdata,int minfreq,int m
       z=(int)(((  pRx->getRxFrequency()-minfreq)*xmax)/(maxfreq-minfreq)+0.5);
       p.drawLine(z,0,z,ymax);
 
-      if ( (z =  pRx->get2RxFrequency()) != 0 ) // RTTY demands to lines
+      if ( (z =  pRx->get2RxFrequency()) != 0 ) // RTTY demands two lines
         {
           z=(( z-minfreq)*xmax)/(maxfreq-minfreq);
           p.drawLine(z,0,z,ymax);
@@ -125,6 +130,8 @@ void SpectrumWindow::plotSpectrum(bool overload,float *fftdata,int minfreq,int m
    }
     if ( overload )
             p.setPen ( Qt::red );
+    else
+      p.setPen ( Qt::black );
     for ( int i = 1;i < xmax;i++ )
     {
 
@@ -169,7 +176,7 @@ void SpectrumWindow::plotVector ( QPainter *p )
   xc = xc + 20;
   yc = yc + 20;
   p->setPen ( Qt::green );
-  for(int i=0; i< 11; i++)
+  for(int i=0; i< PHASE_DISPLAY_BUFFER_LENGTH; i++)
   {
     mag=abs(Phase[i]);
     if ( mag > 0.001)
